#!/usr/bin/ruby

require 'ruby_ip_client/ip_client'

# Initializes the IP Lookup Client
# @param username - www.ip-lookups.com username
# @param password - www.ip-lookups.com password
# @constructor
client = RubyIpClient::IpClient.new(
    'username',
    'password'
)
print "\n"


# Submits a synchronous IP Lookup request. The IP is queried in real time and results presented in the response body.
# @param ip - An IPv4 or IPv6 address
# @param engine - An optional engine assignment, see: http://www.ip-lookups.com/en/data-source-engines
# @param storage - An optional storage assignment, see: http://www.ip-lookups.com/en/storages
# @returns string (JSON)
#
# Return example: {"success":true,"results":{"context":{"id":"7044a161c662","ip":"23.105.134.61","state":"COMPLETED","storage":"SYNC-API-2017-02","engine":"IV1","interface":"Sync API","cost":"0.01000","timeStamp":"2017-02-18 18:27:50.267098+08"},"geolocation":{"country":"United States","region":"Arizona","countryCode":"US","regionCode":"AZ","city":"Phoenix","zip":"85054","latitude":"33.67480","longitude":"-111.95190","radius":1000,"timeZone":"America\/Phoenix","averageIncome":null,"populationDensity":null,"dmaCode":753},"network":{"connectionType":"HOSTING","asn":"15003","asnOrganization":"Nobis Technology Group, LLC","isp":"Nobis Technology Group, LLC","ispOrganization":"Nobis Technology Group, LLC","domain":"ubiquity.io","registeredCountry":"United States","registeredCountryCode":"US","isRoutable":true},"threatIntelligence":{"threatLevel":"VERY_HIGH","threatIntelligenceScore":"1.00000","genericBlacklistMatch":true,"proxyBlacklistMatch":true,"torBlacklistMatch":false,"vpnBlacklistMatch":true,"malwareBlacklistMatch":false,"spywareBlacklistMatch":false,"hijackBlacklistMatch":false,"crawlerBlacklistMatch":false,"botBlacklistMatch":false,"spamBotBlacklistMatch":false,"exploitBotBlacklistMatch":false,"dshieldBlacklistMatch":false}}}
print client.submit_sync_lookup('85.10.208.227', 'IV1', 'SDK-TEST')
print "\n\n"

# Sets the callback URL for asynchronous IP lookups. Read more about the concept of asynchronous IP lookups @ http://www.ip-lookups.com/en/asynchronous-ip-lookup-api
# @param url - callback url on your server
# @returns string (JSON)
#
# Return example: {"success":true,"results":{"url":"http:\/\/user:pass@www.your-server.com\/path\/file"}}
print client.set_async_callback_url('http://user:pass@www.your-server.com/path/file')
print "\n\n"

# Submits asynchronous IP Lookups containing up to 1,000 IPs per request. Results are sent back asynchronously to a callback URL on your server.
# @param ips - A list of IPv4 or IPv6 addresses
# @param engine - An optional engine assignment, see: http://www.ip-lookups.com/en/data-source-engines
# @param storage - An optional storage assignment, see: http://www.ip-lookups.com/en/storages
# @returns string (JSON)
#
# Return example: {"success":true,"results":{"acceptedIps":[{"id":"58cc4f7c4afc","ip":"85.10.208.227"},{"id":"d40499b8605c","ip":"85.10.208.228"},{"id":"8bdc66d4ce52","ip":"85.208.221.221"}],"rejectedIps":[],"acceptedIpCount":3,"rejectedIpCount":0,"totalCount":3,"cost":0.03,"storage":"ASYNC-API-2017-02","engine":"IV1"}}
print client.submit_async_lookup(['85.10.208.227', '85.10.208.228'])
print "\n\n"

# Returns the remaining balance (EUR) in your account.
# @returns string (JSON)
#
# Return example: {"success":true,"results":{"balance":"5878.24600"}}
print client.get_balance
print "\n\n"